The toxicity equivalence range (TEQR) design, is a frequentist up-down design patterned after the modified toxicity probability interval design. The TEQR design extends the well known 3+3 design to allow for: an explicit target range for the dose limiting toxicity (DLT) rate, more than 6 subjects at the maximum tolerated dose (MTD), and specification of a too-toxic rate, which closes a dose level.
The TEQR is better than the 3+3 when compared on: 1) the number of times the dose at or nearest the target toxicity level was selected as the MTD, 2) the number of subjects assigned to doses levels, at, or nearest the MTD, and 3) the overall trial DLT rate. For sample sizes at the MTD greater that 6 TEQR more accurately and more precisely estimates the rate of toxicity at the MTD because a larger number of subjects are studied at the MTD dose. The TEQR on average uses fewer subjects and provide reasonably comparable results to the continual reassessment method (CRM) in the number of times the dose at or nearest the target toxicity level was selected as the MTD and the number of subjects assigned doses, at, or nearest that target and in overall DLT rate.
teqrDG(TotalN,pTarget,eq1,eq2,tootoxic)output<-teqrDG(TotalN=12,pTarget=0.2,eq1=0.05,eq2=0.05,tootoxic=0.34)
output
Run the code above in your browser using DataLab